MongoDb

Struct MongoDb 

pub struct MongoDb(pub Database);

Tuple Fields

0: Database

Methods from Deref<Target = Database>

pub fn name(&self) -> &str

Gets the name of the Database.

pub fn selection_criteria(&self) -> Option<&SelectionCriteria>

Gets the read preference of the Database.

pub fn read_concern(&self) -> Option<&ReadConcern>

Gets the read concern of the Database.

pub fn write_concern(&self) -> Option<&WriteConcern>

Gets the write concern of the Database.

pub fn collection<T>(&self, name: &str) -> Collection<T>

Gets a handle to a collection in this database with the provided name. The Collection options (e.g. read preference and write concern) will default to those of this Database.

For more information on how the generic parameter T is used, check out the Collection documentation.

This method does not send or receive anything across the wire to the database, so it can be used repeatedly without incurring any costs from I/O.

pub fn collection_with_options<T>( &self, name: &str, options: CollectionOptions, ) -> Collection<T>

Gets a handle to a collection in this database with the provided name. Operations done with this Collection will use the options specified by options and will otherwise default to those of this Database.

For more information on how the generic parameter T is used, check out the Collection documentation.

This method does not send or receive anything across the wire to the database, so it can be used repeatedly without incurring any costs from I/O.

pub async fn drop( &self, options: impl Into<Option<DropDatabaseOptions>>, ) -> Result<(), Error>

Drops the database, deleting all data, collections, and indexes stored in it.

pub async fn drop_with_session( &self, options: impl Into<Option<DropDatabaseOptions>>, session: &mut ClientSession, ) -> Result<(), Error>

Drops the database, deleting all data, collections, and indexes stored in it using the provided ClientSession.

pub async fn list_collections( &self, filter: impl Into<Option<Document>>, options: impl Into<Option<ListCollectionsOptions>>, ) -> Result<Cursor<CollectionSpecification>, Error>

Gets information about each of the collections in the database. The cursor will yield a document pertaining to each collection in the database.

pub async fn list_collections_with_session( &self, filter: impl Into<Option<Document>>, options: impl Into<Option<ListCollectionsOptions>>, session: &mut ClientSession, ) -> Result<SessionCursor<CollectionSpecification>, Error>

Gets information about each of the collections in the database using the provided ClientSession. The cursor will yield a document pertaining to each collection in the database.

pub async fn list_collection_names( &self, filter: impl Into<Option<Document>>, ) -> Result<Vec<String>, Error>

Gets the names of the collections in the database.

pub async fn list_collection_names_with_session( &self, filter: impl Into<Option<Document>>, session: &mut ClientSession, ) -> Result<Vec<String>, Error>

Gets the names of the collections in the database using the provided ClientSession.

pub async fn create_collection( &self, name: impl AsRef<str>, options: impl Into<Option<CreateCollectionOptions>>, ) -> Result<(), Error>

Creates a new collection in the database with the given name and options.

Note that MongoDB creates collections implicitly when data is inserted, so this method is not needed if no special options are required.

pub async fn create_collection_with_session( &self, name: impl AsRef<str>, options: impl Into<Option<CreateCollectionOptions>>, session: &mut ClientSession, ) -> Result<(), Error>

Creates a new collection in the database with the given name and options using the provided ClientSession.

Note that MongoDB creates collections implicitly when data is inserted, so this method is not needed if no special options are required.

pub async fn run_command( &self, command: Document, selection_criteria: impl Into<Option<SelectionCriteria>>, ) -> Result<Document, Error>

Runs a database-level command.

Note that no inspection is done on doc, so the command will not use the database’s default read concern or write concern. If specific read concern or write concern is desired, it must be specified manually.

pub async fn run_command_with_session( &self, command: Document, selection_criteria: impl Into<Option<SelectionCriteria>>, session: &mut ClientSession, ) -> Result<Document, Error>

Runs a database-level command using the provided ClientSession.

If the ClientSession provided is currently in a transaction, command must not specify a read concern. If this operation is the first operation in the transaction, the read concern associated with the transaction will be inherited.

Otherwise no inspection is done on command, so the command will not use the database’s default read concern or write concern. If specific read concern or write concern is desired, it must be specified manually.

pub async fn aggregate( &self, pipeline: impl IntoIterator<Item = Document>, options: impl Into<Option<AggregateOptions>>, ) -> Result<Cursor<Document>, Error>

Runs an aggregation operation.

See the documentation here for more information on aggregations.

pub async fn aggregate_with_session( &self, pipeline: impl IntoIterator<Item = Document>, options: impl Into<Option<AggregateOptions>>, session: &mut ClientSession, ) -> Result<SessionCursor<Document>, Error>

Runs an aggregation operation with the provided ClientSession.

See the documentation here for more information on aggregations.

pub async fn watch( &self, pipeline: impl IntoIterator<Item = Document>, options: impl Into<Option<ChangeStreamOptions>>, ) -> Result<ChangeStream<ChangeStreamEvent<Document>>, Error>

Starts a new ChangeStream that receives events for all changes in this database. The stream does not observe changes from system collections and cannot be started on “config”, “local” or “admin” databases.

See the documentation here on change streams.

Change streams require either a “majority” read concern or no read concern. Anything else will cause a server error.

Note that using a $project stage to remove any of the _id, operationType or ns fields will cause an error. The driver requires these fields to support resumability. For more information on resumability, see the documentation for ChangeStream

If the pipeline alters the structure of the returned events, the parsed type will need to be changed via ChangeStream::with_type.

pub async fn watch_with_session( &self, pipeline: impl IntoIterator<Item = Document>, options: impl Into<Option<ChangeStreamOptions>>, session: &mut ClientSession, ) -> Result<SessionChangeStream<ChangeStreamEvent<Document>>, Error>

Starts a new SessionChangeStream that receives events for all changes in this database using the provided ClientSession. See Database::watch for more information.

pub fn gridfs_bucket( &self, options: impl Into<Option<GridFsBucketOptions>>, ) -> GridFsBucket

Creates a new GridFsBucket in the database with the given options.